@@ -23,7 +23,8 @@ import numbers
 from preggy import create_assertions
 
 
-REMOVE_COLORS_REGEX = re.compile(r'\033\[\d+m')
+REMOVE_COLORS_REGEX = re.compile(r'\033\[[0-9]*m')
+REMOVE_COLORS_REGEX2 = re.compile(r'\x1b\[[0-9]*m')
 
 
 #-------------------------------------------------------------------------------------------------
@@ -53,7 +54,12 @@ def _compare_strings(expected, topic):
         topic = topic.decode('utf-8')
     if isinstance(expected, (binary_type, )):
         expected = expected.decode('utf-8')
-    _filter_str = lambda s: REMOVE_COLORS_REGEX.sub('', s.strip().lower().replace(' ', '').replace('\n', ''))
+
+    _filter_str = lambda s: s.strip().lower().replace(' ', '').replace('\n', '')
+    expected = _filter_str(expected)
+    expected = REMOVE_COLORS_REGEX.sub('', expected)
+    expected = REMOVE_COLORS_REGEX2.sub('', expected)
+
     return _filter_str(expected) == _filter_str(topic)
 
 
